@@ -21,13 +21,14 @@
 #'
 #' @examples
 #' library(smplot2)
-#' sm_common_ylabel('My y-axis')
-
-sm_common_ylabel <- function(label = '', size=17, x = 0.5, y = 0.52,
-                             fontface='plain', angle=90) {
+#' sm_common_ylabel("My y-axis")
+sm_common_ylabel <- function(label = "", size = 17, x = 0.5, y = 0.52,
+                             fontface = "plain", angle = 90) {
   layer <- ggdraw()
-  label <- draw_label(label, size = size, x = x, y = y,
-                      fontface = fontface, angle=angle)
+  label <- draw_label(label,
+    size = size, x = x, y = y,
+    fontface = fontface, angle = angle
+  )
 
-  return(list(layer+label)[[1]])
+  return(list(layer + label)[[1]])
 }
