@@ -72,40 +72,43 @@
 #' library(smplot2)
 #' library(ggplot2)
 #'
-#' day1 = rnorm(20,0,1)
-#' day2 = rnorm(20,5,1)
-#' day3 = rnorm(20,6,1.5)
-#' day4 = rnorm(20,7,2)
-#' Subject <- rep(paste0('S',seq(1:20)), 4)
-#' Data <- data.frame(Value = matrix(c(day1,day2,day3,day4),ncol=1))
-#' Day <- rep(c('Day 1', 'Day 2', 'Day 3', 'Day 4'), each = length(day1))
+#' day1 <- rnorm(20, 0, 1)
+#' day2 <- rnorm(20, 5, 1)
+#' day3 <- rnorm(20, 6, 1.5)
+#' day4 <- rnorm(20, 7, 2)
+#' Subject <- rep(paste0("S", seq(1:20)), 4)
+#' Data <- data.frame(Value = matrix(c(day1, day2, day3, day4), ncol = 1))
+#' Day <- rep(c("Day 1", "Day 2", "Day 3", "Day 4"), each = length(day1))
 #' df2 <- cbind(Subject, Data, Day)
 #'
 #' ggplot(data = df2, aes(x = Value, y = Day, color = Day, fill = Day)) +
-#'  sm_forest(sep_level = 2, point_jitter_width = .12,
-#'            errorbar_type = 'ci',
-#'            point.params = list(alpha=0.2)) +
+#'   sm_forest(
+#'     sep_level = 2, point_jitter_width = .12,
+#'     errorbar_type = "ci",
+#'     point.params = list(alpha = 0.2)
+#'   ) +
 #'   scale_color_manual(values = sm_palette(4))
-
 sm_forest <- function(...,
-                      point.params = list(size=  2.5, alpha = 0.3),
-                      avgPoint.params = list(size = 5.5,
-                                             shape = 18),
-                      err.params = list(color = 'black'),
-                      ref.params = list(size = 0.4, color = 'gray80',
-                                        linetype='dashed'),
+                      point.params = list(size = 2.5, alpha = 0.3),
+                      avgPoint.params = list(
+                        size = 5.5,
+                        shape = 18
+                      ),
+                      err.params = list(color = "black"),
+                      ref.params = list(
+                        size = 0.4, color = "gray80",
+                        linetype = "dashed"
+                      ),
                       xintercept = 0,
                       sep_level = 2,
                       point_jitter_width = 0,
-                      errorbar_type = 'ci',
+                      errorbar_type = "ci",
                       points = TRUE,
                       refLine = TRUE,
                       borders = TRUE,
                       legends = FALSE,
                       seed = NULL,
-                      forget = FALSE
-) {
-
+                      forget = FALSE) {
   if (length(seed)) set.seed(seed)
 
   if (point_jitter_width == 0) {
@@ -115,65 +118,90 @@ sm_forest <- function(...,
   params <- list(...)
 
   if (forget == FALSE) {
-    point.params0 = list(size=  2.5, alpha = 0.3)
-    point.params0  = modifyList(point.params0 , params)
-    avgPoint.params0 = list(size = 5.5, shape = 18)
-    avgPoint.params0 = modifyList(avgPoint.params0, params)
-    err.params0 = list(color = 'black')
-    err.params0 = modifyList(err.params0, params)
-    ref.params0 = list(size = 0.4, color = 'gray80', linetype='dashed')
+    point.params0 <- list(size = 2.5, alpha = 0.3)
+    point.params0 <- modifyList(point.params0, params)
+    avgPoint.params0 <- list(size = 5.5, shape = 18)
+    avgPoint.params0 <- modifyList(avgPoint.params0, params)
+    err.params0 <- list(color = "black")
+    err.params0 <- modifyList(err.params0, params)
+    ref.params0 <- list(size = 0.4, color = "gray80", linetype = "dashed")
 
     point.params <- modifyList(point.params0, point.params)
     avgPoint.params <- modifyList(avgPoint.params0, avgPoint.params)
     err.params <- modifyList(err.params0, err.params)
     ref.params <- modifyList(ref.params0, ref.params)
-
-  } else if (forget == TRUE){
+  } else if (forget == TRUE) {
     point.params <- modifyList(params, point.params)
     avgPoint.params <- modifyList(params, avgPoint.params)
     err.params <- modifyList(params, err.params)
-    #ref.params <- modifyList(params, ref.params)
+    # ref.params <- modifyList(params, ref.params)
   }
 
 
 
-  if (errorbar_type == 'se') {
-    errPlot <- do.call('stat_summary',
-                       modifyList(list(fun.data = mean_se,
-                                       geom = 'linerange'), err.params))
-  } else if (errorbar_type == 'sd') {
-    errPlot <- do.call('stat_summary',
-                       modifyList(list(fun = mean,
-                                       fun.min = function(x) mean(x) - sd(x),
-                                       fun.max = function(x) mean(x) + sd(x),
-                                       geom = 'linerange'),
-                                  err.params))
-  } else if (errorbar_type == 'ci') {
-    errPlot <- do.call('stat_summary',
-                       modifyList(list(fun.data = mean_cl_boot,
-                                       geom = 'linerange'), err.params))
+  if (errorbar_type == "se") {
+    errPlot <- do.call(
+      "stat_summary",
+      modifyList(list(
+        fun.data = mean_se,
+        geom = "linerange"
+      ), err.params)
+    )
+  } else if (errorbar_type == "sd") {
+    errPlot <- do.call(
+      "stat_summary",
+      modifyList(
+        list(
+          fun = mean,
+          fun.min = function(x) mean(x) - sd(x),
+          fun.max = function(x) mean(x) + sd(x),
+          geom = "linerange"
+        ),
+        err.params
+      )
+    )
+  } else if (errorbar_type == "ci") {
+    errPlot <- do.call(
+      "stat_summary",
+      modifyList(list(
+        fun.data = mean_cl_boot,
+        geom = "linerange"
+      ), err.params)
+    )
   } else {
     stop('Wrong input argument for errorbar_type. Please write either "se", "sd" or "ci"')
   }
 
 
-  position_nudge_vector <- c(-sep_level/10,0)
+  position_nudge_vector <- c(-sep_level / 10, 0)
 
-  refLinePlot <- do.call('geom_vline',
-                         modifyList(list(xintercept=xintercept), ref.params))
+  refLinePlot <- do.call(
+    "geom_vline",
+    modifyList(list(xintercept = xintercept), ref.params)
+  )
 
 
-  pointPlot <- do.call('geom_point',
-                       modifyList(list(position = position_jitternudge(jitter.width=point_jitter_width,
-                                                                       jitter.height=point_jitter_width,
-                                                                       nudge.y = 0,
-                                                                       nudge.x = position_nudge_vector[1])),
-                                  point.params))
+  pointPlot <- do.call(
+    "geom_point",
+    modifyList(
+      list(position = position_jitternudge(
+        jitter.width = point_jitter_width,
+        jitter.height = point_jitter_width,
+        nudge.y = 0,
+        nudge.x = position_nudge_vector[1]
+      )),
+      point.params
+    )
+  )
 
-  avgPointPlot <- do.call('stat_summary',
-                          modifyList(list(fun = mean,
-                                          geom = 'point',
-                                          position = position_nudge(y = position_nudge_vector[2])), avgPoint.params))
+  avgPointPlot <- do.call(
+    "stat_summary",
+    modifyList(list(
+      fun = mean,
+      geom = "point",
+      position = position_nudge(y = position_nudge_vector[2])
+    ), avgPoint.params)
+  )
 
 
 
@@ -185,7 +213,8 @@ sm_forest <- function(...,
     refLinePlot <- NULL
   }
 
-  list(refLinePlot,pointPlot,avgPointPlot,errPlot,
-       sm_hgrid(borders=borders,legends=legends))
-
+  list(
+    refLinePlot, pointPlot, avgPointPlot, errPlot,
+    sm_hgrid(borders = borders, legends = legends)
+  )
 }
