@@ -44,53 +44,66 @@
 #' @examples
 #' library(ggplot2)
 #' library(smplot2)
-#
+#' #
 #' set.seed(2)
-#' data=data.frame(value=rnorm(1000))
-#' data2 = data.frame(value=rnorm(1000,5,1))
+#' data <- data.frame(value = rnorm(1000))
+#' data2 <- data.frame(value = rnorm(1000, 5, 1))
 #'
-#' data$day <- 'day1'
-#' data2$day <- 'day2'
-#' rbind(data,data2) -> df
+#' data$day <- "day1"
+#' data2$day <- "day2"
+#' rbind(data, data2) -> df
 #'
-#' ggplot(data = data, aes(x=value)) +
-#' sm_hist()
+#' ggplot(data = data, aes(x = value)) +
+#'   sm_hist()
 #'
-#' ggplot(data = df, aes(x=value, fill=day, color = day)) +
-#' sm_hist(hist.params = list(binwidth = 1/2, alpha = 0.3),
-#'        density.params = list(fill='transparent', size = 0.8),
-#'        rug.params = list(alpha = 0.8)) +
-#'  scale_color_manual(values = sm_palette(2)) +
+#' ggplot(data = df, aes(x = value, fill = day, color = day)) +
+#'   sm_hist(
+#'     hist.params = list(binwidth = 1 / 2, alpha = 0.3),
+#'     density.params = list(fill = "transparent", size = 0.8),
+#'     rug.params = list(alpha = 0.8)
+#'   ) +
+#'   scale_color_manual(values = sm_palette(2)) +
 #'   scale_fill_manual(values = sm_palette(2))
 #'
 sm_hist <- function(...,
-                    hist.params = list(binwidth = 1/2, fill = sm_color('blue'),
-                                       color = 'white',
-                                       alpha = 0.4),
-                    density.params = list(color=sm_color('blue'), size =0.8,
-                                          fill = 'transparent'),
-                    rug.params = list(color = sm_color('blue'), alpha = 0.8,
-                                      size = 0.4),
+                    hist.params = list(
+                      binwidth = 1 / 2, fill = sm_color("blue"),
+                      color = "white",
+                      alpha = 0.4
+                    ),
+                    density.params = list(
+                      color = sm_color("blue"), size = 0.8,
+                      fill = "transparent"
+                    ),
+                    rug.params = list(
+                      color = sm_color("blue"), alpha = 0.8,
+                      size = 0.4
+                    ),
                     histogram = TRUE,
                     density = TRUE,
                     rug = TRUE,
                     borders = FALSE,
                     legends = FALSE,
                     forget = FALSE) {
-
   params <- list(...)
 
   if (forget == FALSE) {
-    hist.params0 = list(binwidth = 1/2, fill = sm_color('blue'),
-                        color = 'white',
-                        alpha = 0.4)
-    hist.params0 = modifyList(hist.params0, params)
-    density.params0 = list(color=sm_color('blue'), size =0.8,
-                           fill = 'transparent')
-    density.params0 = modifyList(density.params0, params)
-    rug.params0 = list(color = sm_color('blue'), alpha = 0.8,
-                       size = 0.4)
-    rug.params0 = modifyList(rug.params0, params)
+    hist.params0 <- list(
+      binwidth = 1 / 2, fill = sm_color("blue"),
+      color = "white",
+      alpha = 0.4
+    )
+    hist.params0 <- modifyList(hist.params0, params)
+    density.params0 <- list(
+      color = sm_color("blue"), size = 0.8,
+      fill = "transparent"
+    )
+    density.params0 <- modifyList(density.params0, params)
+    rug.params0 <- list(
+      color = sm_color("blue"), alpha = 0.8,
+      size = 0.4
+    )
+    rug.params0 <- modifyList(rug.params0, params)
 
     hist.params <- modifyList(hist.params0, hist.params)
     density.params <- modifyList(density.params0, density.params)
@@ -102,15 +115,23 @@ sm_hist <- function(...,
   }
 
 
-  histPlot <- do.call('geom_histogram',
-                      modifyList(list(), hist.params))
+  histPlot <- do.call(
+    "geom_histogram",
+    modifyList(list(), hist.params)
+  )
 
-  densityPlot <- do.call('geom_density',
-                         modifyList(list(aes(y= hist.params$binwidth* after_stat(count))),
-                                    density.params))
+  densityPlot <- do.call(
+    "geom_density",
+    modifyList(
+      list(aes(y = hist.params$binwidth * after_stat(count))),
+      density.params
+    )
+  )
 
-  rugPlot <- do.call('geom_rug',
-                     modifyList(list(), rug.params))
+  rugPlot <- do.call(
+    "geom_rug",
+    modifyList(list(), rug.params)
+  )
 
   if (density == FALSE) {
     densityPlot <- NULL
@@ -124,10 +145,11 @@ sm_hist <- function(...,
     histPlot <- NULL
   }
 
-  list(histPlot,densityPlot,rugPlot,
-       sm_hgrid(borders=borders, legends=legends),
-       ggplot2::ylab('Count'))
-
+  list(
+    histPlot, densityPlot, rugPlot,
+    sm_hgrid(borders = borders, legends = legends),
+    ggplot2::ylab("Count")
+  )
 }
 
-globalVariables(c('count'))
+globalVariables(c("count"))
